@@ -133,14 +133,12 @@ def filterQuotesByBook(db, book, min_likes=0):
 def exportQuotes(quotes, saveFile):
 	from grtoolkit.Storage import File
 	save = File(saveFile, enc=1)
-	try:
-		for i in range(0,len(quotes)):
-			if i == 1:
-				save.write(quote)
-			else:
-				save.append(quote,newline=True)
-	except:
-		pass
+
+	for i in range(0,len(quotes)):
+		if i == 1:
+			save.write(quotes[i])
+		else:
+			save.append(quotes[i],newline=True)
 
 
 
