@@ -42,12 +42,14 @@ class File:
 
     def append(self, content, newline=True):
         """Appends content to existing file"""
-
+        nextLine = "\n"
         if self.encode != None:
+            nextLine = nextLine.encode(self.encode)
             content = content.encode(self.encode)
 
+
         f = open(self.fileName, "a")
-        f.write("\n" + content) if newline else f.write(content)
+        f.write(nextLine + content) if newline else f.write(content)
         f.close()
 
     def read(self):
